package com.qmth.teachcloud.report.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.qmth.teachcloud.report.business.bean.result.TeacherRankForClazz;
import com.qmth.teachcloud.report.business.entity.TAExamCourseClazzTeacher;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @Description: 班级下授课教师维度mapper
 * @Author: CaoZixuan
 * @Date: 2022-06-24
 */
public interface TAExamCourseClazzTeacherMapper extends BaseMapper<TAExamCourseClazzTeacher> {

    /**
     * 开课院长看板 - 教师各课堂成绩排名
     *
     * @param page             分页参数
     * @param schoolId         学校id
     * @param semester         学期
     * @param examId           考试id
     * @param courseCode       课程编号
     * @param inspectCollegeId 开课学院id
     * @param collegeIds       数据权限
     * @param column           排序列
     * @param order            排序方式
     * @return 分页结果
     */
    IPage<TeacherRankForClazz> listClassRank(@Param("page") Page<TeacherRankForClazz> page, @Param("schoolId") Long schoolId, @Param("semester") String semester, @Param("examId") Long examId, @Param("courseCode") String courseCode, @Param("inspectCollegeId") Long inspectCollegeId, @Param("collegeIds") List<Long> collegeIds, @Param("column") String column, @Param("order") String order);

    /**
     * 开课院长看板 - 开课课程考试总览-教师各课堂成绩排名接口
     *
     * @param page       分页信息
     * @param schoolId   学校id
     * @param semester   学期
     * @param examId     考试id
     * @param courseCode 课程编号
     * @param column     排序列
     * @param order      排序方式
     * @return 分页结果
     */
    IPage<TeacherRankForClazz> surveyTeacherTeacherView(@Param("page") Page<TeacherRankForClazz> page, @Param("schoolId") Long schoolId, @Param("semester") String semester, @Param("examId") Long examId, @Param("courseCode") String courseCode, @Param("column") String column, @Param("order") String order);

    /**
     * 教务处看板 - 全校课程考试分析 - 教师各课堂成绩排名
     *
     * @param page       分页信息
     * @param schoolId   学校id
     * @param semester   学期
     * @param examId     考试id
     * @param courseCode 课程编号
     * @param column     排序列
     * @param order      排序方式
     * @return 分页结果
     */
    IPage<TeacherRankForClazz> listTeacherClassRank(@Param("page") Page<TeacherRankForClazz> page, @Param("schoolId") Long schoolId, @Param("semester") String semester, @Param("examId") Long examId, @Param("courseCode") String courseCode, @Param("column") String column, @Param("order") String order);

    /**
     *
     * @param page 分页信息
     * @param schoolId 学校id
     * @param semester 学期
     * @param examId 考试id
     * @param inspectCollegeId 考察学院id
     * @param courseCode 课程编号
     * @param teacherId 教师id
     * @param collegeIds 数据权限
     * @param column 排序列
     * @param order 排序方式
     * @return 分页结果
     */
    IPage<TeacherRankForClazz> listAllTeacherClassRank(@Param("page") Page<TeacherRankForClazz> page, @Param("schoolId") Long schoolId, @Param("semester") String semester, @Param("examId") Long examId, @Param("inspectCollegeId") Long inspectCollegeId, @Param("courseCode") String courseCode, @Param("teacherId") Long teacherId, @Param("collegeIds") List<Long> collegeIds, @Param("column") String column, @Param("order") String order);
}
