package com.qmth.teachcloud.report.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.teachcloud.report.business.bean.result.TeacherRankForClazz;
import com.qmth.teachcloud.report.business.entity.TAExamCourseClazzTeacher;
import com.qmth.teachcloud.report.business.enums.OrderEnum;
import com.qmth.teachcloud.report.business.enums.SemesterEnum;

/**
 * @Description: 参考课程班级下授课教师维度接口
 * @Author: CaoZixuan
 * @Date: 2022-06-24
 */
public interface TAExamCourseClazzTeacherService extends IService<TAExamCourseClazzTeacher> {

    /**
     * 开课院长看板 - 教师各课堂成绩排名
     *
     * @param semester         学期
     * @param examId           考试id
     * @param courseCode       课程编号
     * @param inspectCollegeId 开课学院id
     * @param pageNumber       分页页数
     * @param pageSize         分页容量
     * @param column           排序列
     * @param order            排序方式
     * @return 分页查询结果
     */
    IPage<TeacherRankForClazz> listClassRank(SemesterEnum semester, Long examId, String courseCode, Long inspectCollegeId, Integer pageNumber, Integer pageSize, String column, OrderEnum order);


    /**
     * 开课院长看板 - 开课课程考试总览-教师各课堂成绩排名接口
     *
     * @param schoolId   学校id
     * @param semester   学期
     * @param examId     考试id
     * @param courseCode 课程编号
     * @param pageNumber 分页页数
     * @param pageSize   分页容量
     * @param column     排序列
     * @param order      排序方式
     * @return 分页结果
     */
    IPage<TeacherRankForClazz> surveyTeacherTeacherView(Long schoolId, SemesterEnum semester, Long examId, String courseCode, Integer pageNumber, Integer pageSize, String column, OrderEnum order);

    /**
     * 教务处看板 - 全校课程考试分析 - 教师各课堂成绩排名
     * @param semester 学期
     * @param examId 考试id
     * @param courseCode 课程编号
     * @param pageNumber 分页页数
     * @param pageSize 分页容量
     * @param column 排序列
     * @param order 排序方式
     * @return 分页结果
     */
    IPage<TeacherRankForClazz> listTeacherClassRank(SemesterEnum semester, Long examId, String courseCode, Integer pageNumber, Integer pageSize, String column, OrderEnum order);

    /**
     * 教务处看板 - 全校教师各课堂成绩排名
     * @param semester 学期
     * @param examId 考试id
     * @param inspectCollegeId 考察学院id
     * @param courseCode 课程编号
     * @param teacherId 教师id
     * @param pageNumber 分页页数
     * @param pageSize 分页容量
     * @param column 排序列
     * @param order 排序方式
     * @return 分页结果
     */
    IPage<TeacherRankForClazz> listAllTeacherClassRank(SemesterEnum semester, Long examId, Long inspectCollegeId, String courseCode, Long teacherId, Integer pageNumber, Integer pageSize, String column, OrderEnum order);
}
