package com.qmth.teachcloud.report.business.service.impl;

import com.qmth.teachcloud.report.business.service.AnalyzeForReportService;
import com.qmth.teachcloud.report.business.service.DataAnalyzeService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.concurrent.CompletableFuture;

/**
 * @Description: 数据分析计算线程服务类
 * @Author: CaoZixuan
 * @Date: 2022-05-11
 */
@Service
public class DataAnalyzeServiceImpl implements DataAnalyzeService {
    @Resource
    private AnalyzeForReportService analyzeForReportService;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void predecessorAnalyzeTask(Long examId, String courseCode) throws Exception {
        analyzeForReportService.buildAnalyzeExamCourse(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseRecord(examId, courseCode);
        analyzeForReportService.buildAnalyzePaperStruct(examId, courseCode);
        analyzeForReportService.buildAnalyzePointScoreRate(examId, courseCode);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void asyncAnalyzeTask(Long examId, String courseCode) {
        analyzeForReportService.buildAnalyzeExamCourseCollegeInspect(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseClazz(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseCollegeInspectDio(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseTeacherDio(examId, courseCode);
        analyzeForReportService.buildExamPaperDifficult(examId, courseCode);
        analyzeForReportService.buildExamPaperTeacherDifficult(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamTotal(examId);
        analyzeForReportService.buildAnalyzeExamCourseCollegeTeacher(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseClazzTeacher(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseTeacher(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseTeacherCollegeDio(examId, courseCode);
        analyzeForReportService.buildAnalyzeExamCourseTeacherCollegeDifficult(examId, courseCode);
        analyzeForReportService.buildAnalyzeCollegePaperStruct(examId, courseCode);
        analyzeForReportService.buildAnalyzeTeacherPaperStruct(examId, courseCode);
        analyzeForReportService.buildAnalyzeTeacherCollegePaperStruct(examId, courseCode);
    }

    @Override
    public CompletableFuture<Boolean> dataCalculate(Long examId, String courseCode) throws Exception {
        this.predecessorAnalyzeTask(examId,courseCode);
        this.asyncAnalyzeTask(examId, courseCode);
        return CompletableFuture.completedFuture(true);
    }
}
