package com.qmth.teachcloud.report.business.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.service.SysOrgService;
import com.qmth.teachcloud.common.util.ServletUtil;
import com.qmth.teachcloud.report.business.bean.result.TAExamCourseCollegeTeacherResult;
import com.qmth.teachcloud.report.business.bean.result.TeacherClassRankResult;
import com.qmth.teachcloud.report.business.bean.result.TeacherRankForClazz;
import com.qmth.teachcloud.report.business.entity.TAExamCourseClazzTeacher;
import com.qmth.teachcloud.report.business.enums.OrderEnum;
import com.qmth.teachcloud.report.business.enums.SemesterEnum;
import com.qmth.teachcloud.report.business.mapper.TAExamCourseClazzTeacherMapper;
import com.qmth.teachcloud.report.business.service.TAExamCourseClazzTeacherService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Objects;

/**
 * @Description: 参考课程班级下授课教师维度接口实现类
 * @Author: CaoZixuan
 * @Date: 2022-06-24
 */
@Service
public class TAExamCourseClazzTeacherServiceImpl extends ServiceImpl<TAExamCourseClazzTeacherMapper, TAExamCourseClazzTeacher> implements TAExamCourseClazzTeacherService {
    @Resource
    private SysOrgService sysOrgService;

    @Override
    public IPage<TeacherRankForClazz> listClassRank(SemesterEnum semester, Long examId, String courseCode, Long inspectCollegeId, Integer pageNumber, Integer pageSize, String column, OrderEnum order) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        Page<TeacherRankForClazz> page = new Page<>(pageNumber, pageSize);
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        List<Long> collegeIds = sysOrgService.findCollegeIds(sysUser.getOrgId());
        if (Objects.nonNull(collegeIds) && collegeIds.size() > 0) {
            return this.baseMapper.listClassRank(page, schoolId, Objects.nonNull(semester) ? semester.name() : null, examId, courseCode, inspectCollegeId, collegeIds, column, Objects.nonNull(order) ? order.name() : null);
        } else {
            return this.baseMapper.listClassRank(page, schoolId, Objects.nonNull(semester) ? semester.name() : null, examId, courseCode, inspectCollegeId, Objects.nonNull(sysUser.getOrgId()) ? Arrays.asList(sysUser.getOrgId()) : null, column, Objects.nonNull(order) ? order.name() : null);
        }
    }

    @Override
    public IPage<TeacherRankForClazz> surveyTeacherTeacherView(Long schoolId, SemesterEnum semester, Long examId, String courseCode, Integer pageNumber, Integer pageSize, String column, OrderEnum order) {
        Page<TeacherRankForClazz> page = new Page<>(pageNumber, pageSize);
        return this.baseMapper.surveyTeacherTeacherView(page, schoolId, Objects.nonNull(semester) ? semester.name() : null, examId, courseCode, column, Objects.nonNull(order) ? order.name() : null);
    }

    @Override
    public IPage<TeacherRankForClazz> listTeacherClassRank(SemesterEnum semester, Long examId, String courseCode, Integer pageNumber, Integer pageSize, String column, OrderEnum order) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        Page<TeacherRankForClazz> page = new Page<>(pageNumber, pageSize);
        return this.baseMapper.listTeacherClassRank(page, schoolId, Objects.nonNull(semester) ? semester.name() : null, examId, courseCode, column, Objects.nonNull(order) ? order.name() : null);
    }

    @Override
    public IPage<TeacherRankForClazz> listAllTeacherClassRank(SemesterEnum semester, Long examId, Long inspectCollegeId, String courseCode, Long teacherId, Integer pageNumber, Integer pageSize, String column, OrderEnum order) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        Page<TeacherRankForClazz> page = new Page<>(pageNumber, pageSize);
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        List<Long> collegeIds = sysOrgService.findCollegeIds(sysUser.getOrgId());
        if (Objects.nonNull(collegeIds) && collegeIds.size() > 0) {
            return this.baseMapper.listAllTeacherClassRank(page, schoolId, Objects.nonNull(semester) ? semester.name() : null, examId, inspectCollegeId, courseCode, teacherId, collegeIds, column, Objects.nonNull(order) ? order.name() : null);
        } else {
            return this.baseMapper.listAllTeacherClassRank(page, schoolId, Objects.nonNull(semester) ? semester.name() : null, examId, inspectCollegeId, courseCode, teacherId, Objects.nonNull(sysUser.getOrgId()) ? Collections.singletonList(sysUser.getOrgId()) : null, column, Objects.nonNull(order) ? order.name() : null);
        }
    }
}
